@@ -189,16 +189,8 @@ class FixedRateBond(BaseModel):
             raise ValueError
         return  v
 
-    @validator('maturity')
-    def valid_maturity(cls, v): 
-        try:
-            adate = dt64(v)
-        except:
-            raise ValueError
-        return  v
-
-    @validator('issue_date')
-    def valid_issue_date(cls, v): 
+    @validator('issue_date', 'maturity')
+    def valid_date(cls, v): 
         try:
             adate = dt64(v)
         except:
@@ -258,3 +250,23 @@ class BondRisk(BaseModel):
     basis_point_value: Optional[float] = None
     yield_value_basis_point: Optional[float] = None
     
+
+class CashFlow(BaseModel):
+    date: str 
+    amount: float
+
+    @validator('date')
+    def valid_date(cls, v): 
+        try:
+            adate = dt64(v)
+        except:
+            raise ValueError
+        return  v
+
+    @validator('amount')
+    def valid_float(cls, v): 
+        try:
+            anumber = float(v)
+        except:
+            raise ValueError
+        return  v
\ No newline at end of file
